/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.prestosql.execution.resourcegroups;

import io.prestosql.spi.PrestoException;
import io.prestosql.spi.resourcegroups.ResourceGroupId;

import static io.prestosql.spi.StandardErrorCode.QUERY_QUEUE_FULL;
import static java.lang.String.format;
import static java.util.Objects.requireNonNull;

public class QueryQueueFullException
        extends PrestoException
{
    private final ResourceGroupId resourceGroup;

    public QueryQueueFullException(ResourceGroupId resourceGroup)
    {
        super(QUERY_QUEUE_FULL, format("Too many queued queries for \"%s\"", resourceGroup));
        this.resourceGroup = requireNonNull(resourceGroup, "resourceGroup is null");
    }

    public ResourceGroupId getResourceGroup()
    {
        return resourceGroup;
    }
}
