/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.prestosql.operator.exchange;

import com.google.common.util.concurrent.ListenableFuture;
import io.prestosql.spi.Page;

import static io.prestosql.operator.Operator.NOT_BLOCKED;

public interface LocalExchanger
{
    LocalExchanger FINISHED = new LocalExchanger()
    {
        @Override
        public void accept(Page page) {}

        @Override
        public ListenableFuture<?> waitForWriting()
        {
            return NOT_BLOCKED;
        }
    };

    void accept(Page page);

    ListenableFuture<?> waitForWriting();

    default void finish() {}
}
