/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.prestosql.plugin.memory;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.prestosql.spi.connector.ColumnHandle;

import java.util.Objects;

public final class MemoryColumnHandle
        implements ColumnHandle
{
    private final int columnIndex;

    @JsonCreator
    public MemoryColumnHandle(@JsonProperty("columnIndex") int columnIndex)
    {
        this.columnIndex = columnIndex;
    }

    @JsonProperty
    public int getColumnIndex()
    {
        return columnIndex;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(columnIndex);
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        MemoryColumnHandle other = (MemoryColumnHandle) obj;
        return Objects.equals(this.columnIndex, other.columnIndex);
    }

    @Override
    public String toString()
    {
        return Integer.toString(columnIndex);
    }
}
