/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.prestosql.spi.type;

import java.util.Objects;

public class DecimalParseResult
{
    private final Object object;
    private final DecimalType type;

    public DecimalParseResult(Object object, DecimalType type)
    {
        this.object = object;
        this.type = type;
    }

    public Object getObject()
    {
        return object;
    }

    public DecimalType getType()
    {
        return type;
    }

    @Override
    public boolean equals(Object o)
    {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DecimalParseResult that = (DecimalParseResult) o;
        return Objects.equals(object, that.object) &&
                Objects.equals(type, that.type);
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(object, type);
    }

    @Override
    public String toString()
    {
        return "ParseResult{" +
                "object=" + object +
                ", type=" + type +
                '}';
    }
}
